@@ -39,6 +39,10 @@ class Profile:
             kk = len(pixel_max)
         except TypeError:
             pixel_max = [pixel_max] * len(file_paths)
+        try:
+            jj = len(hot_pixel_threshold)
+        except TypeError:
+            hot_pixel_threshold = [hot_pixel_threshold] * len(file_paths)
         for i, f in enumerate(file_paths):
             self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], hot_pixel_threshold=hot_pixel_threshold, transpose=transpose))
         self.q_vectors = None
@@ -326,7 +330,7 @@ class Scan:
                 if self.data['roi1_maxval'][i] > self.pixel_max:
                     to_remove.append(i)
                     continue
-                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold, transpose=self.transpose)
+                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold[i], transpose=self.transpose)
                 if crop_kwargs is None:
                     im.crop(crop_function)
                 else:
@@ -340,9 +344,10 @@ class Scan:
                     self.n_pixels[i] = None
                 else:
                     self.n_pixels[i] = im.n_pixel.n
-            except (ValueError, RuntimeError):
+            except (ValueError, RuntimeError) as e:
+                print(e)
+                print('Current file: ', self.data["file"][i])
                 to_remove.append(i)
-                print('ERROR ON FILE:', self.file_path)
                 continue
         self.R = np.delete(self.R, to_remove)
         self.theta = np.delete(self.theta, to_remove)
